@@ -444,9 +444,21 @@ gsd_housekeeping_manager_stop (GsdHousekeepingManager *manager)
         gsd_ldsm_clean ();
 }
 
+static void
+gsd_housekeeping_manager_finalize (GObject *object)
+{
+        gsd_housekeeping_manager_stop (GSD_HOUSEKEEPING_MANAGER (object));
+
+        G_OBJECT_CLASS (gsd_housekeeping_manager_parent_class)->finalize (object);
+}
+
 static void
 gsd_housekeeping_manager_class_init (GsdHousekeepingManagerClass *klass)
 {
+        GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+        object_class->finalize = gsd_housekeeping_manager_finalize;
+
         g_type_class_add_private (klass, sizeof (GsdHousekeepingManagerPrivate));
 }
 
