@@ -122,8 +122,10 @@ gsd_wacom_stylus_finalize (GObject *object)
 }
 
 static const char *
-get_icon_name_from_type (WacomStylusType type)
+get_icon_name_from_type (const WacomStylus *wstylus)
 {
+	WacomStylusType type = libwacom_stylus_get_type (wstylus);
+
 	switch (type) {
 	case WSTYLUS_INKING:
 	case WSTYLUS_STROKE:
@@ -137,6 +139,8 @@ get_icon_name_from_type (WacomStylusType type)
 	case WSTYLUS_CLASSIC:
 		return "wacom-stylus-classic";
 	default:
+		if (!libwacom_stylus_has_eraser (wstylus))
+			return "wacom-stylus-no-eraser";
 		return "wacom-stylus";
 	}
 }
@@ -158,7 +162,7 @@ gsd_wacom_stylus_new (GsdWacomDevice    *device,
 	stylus->priv->name = g_strdup (libwacom_stylus_get_name (wstylus));
 	stylus->priv->settings = settings;
 	stylus->priv->type = libwacom_stylus_get_type (wstylus);
-	stylus->priv->icon_name = get_icon_name_from_type (stylus->priv->type);
+	stylus->priv->icon_name = get_icon_name_from_type (wstylus);
 	stylus->priv->has_eraser = libwacom_stylus_has_eraser (wstylus);
 	stylus->priv->num_buttons = libwacom_stylus_get_num_buttons (wstylus);
 
@@ -2103,6 +2107,12 @@ gsd_wacom_device_rotation_type_to_name (GsdWacomRotation type)
 	return "none";
 }
 
+GdkDevice *
+gsd_wacom_device_get_gdk_device (GsdWacomDevice *device)
+{
+	return device->priv->gdk_device;
+}
+
 GsdWacomDevice *
 gsd_wacom_device_create_fake (GsdWacomDeviceType  type,
 			      const char         *name,
@@ -2230,3 +2240,27 @@ gsd_wacom_device_create_fake_intuos4 (void)
 
 	return devices;
 }
+
+GList *
+gsd_wacom_device_create_fake_h610pro (void)
+{
+	GsdWacomDevice *device;
+	GList *devices;
+
+	device = gsd_wacom_device_create_fake (WACOM_TYPE_STYLUS,
+					       "Huion H610 Pro",
+					       "Huion H610 Pro stylus");
+	if (!device) {
+		g_warning ("Not appending Huion H610 Pro, libwacom is not new enough");
+		return NULL;
+	}
+
+	devices = g_list_prepend (NULL, device);
+
+	device = gsd_wacom_device_create_fake (WACOM_TYPE_PAD,
+					       "Huion H610 Pro",
+					       "Huion H610 Pro pad");
+	devices = g_list_prepend (devices, device);
+
+	return devices;
+}
