@@ -190,13 +190,12 @@ get_edid (GsdWacomDevice *device)
 	GSettings *gsd_settings;
 	char **edid;
 
-	g_object_get (device, "gdk-device", &gdk_device, NULL);
+	gdk_device = gsd_wacom_device_get_gdk_device (device);
 	if (!gdk_device)
 		goto bail;
 
 	gsd_device = gsd_x11_device_manager_lookup_gdk_device (GSD_X11_DEVICE_MANAGER (gsd_device_manager_get ()),
 							       gdk_device);
-	g_object_unref (gdk_device);
 	if (!gsd_device)
 		goto bail;
 
