@@ -229,6 +229,11 @@ gsd_remote_display_manager_panel_finalize (GObject *object)
         GsdRemoteDisplayManager *manager = GSD_REMOTE_DISPLAY_MANAGER (object);
         g_debug ("Stopping remote_display manager");
 
+        if (manager->priv->vino_watch_id > 0) {
+                g_bus_unwatch_name (manager->priv->vino_watch_id);
+                manager->priv->vino_watch_id = 0;
+        }
+
         if (manager->priv->cancellable != NULL) {
                 g_cancellable_cancel (manager->priv->cancellable);
                 g_clear_object (&manager->priv->cancellable);
@@ -260,6 +265,7 @@ gsd_remote_display_manager_init (GsdRemoteDisplayManager *manager)
 {
 
         manager->priv = GSD_REMOTE_DISPLAY_MANAGER_GET_PRIVATE (manager);
+        manager->priv->cancellable = g_cancellable_new ();
 
         g_debug ("Starting remote-display manager");
 
@@ -296,8 +302,6 @@ gsd_remote_display_manager_init (GsdRemoteDisplayManager *manager)
                                                          (GBusNameAppearedCallback) vino_appeared_cb,
                                                          (GBusNameVanishedCallback) vino_vanished_cb,
                                                          manager, NULL);
-
-
 }
 
 GsdRemoteDisplayManager *
